.. Compat Patcher Core documentation master file, created by
   sphinx-quickstart on Sun Jun 16 17:01:46 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to Compat Patcher Core's documentation!
###################################################


.. include:: ../README.rst



Topics
#################

.. toctree::
   :maxdepth: 2

   startup.rst
   guidelines.rst
   api.rst


Indices and tables
##################################

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

